@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
  
                          edge.h  -  description
@@ -45,6 +45,7 @@ static const int TypeEdge= QGraphicsItem::UserType+2;
 
 class Edge : public QObject, public QGraphicsItem {
 	Q_OBJECT
+	Q_INTERFACES (QGraphicsItem)
 
 public:
 	Edge(GraphicsWidget *, Node*, Node*, float, int, QString, bool, bool, bool);
@@ -98,6 +99,7 @@ private:
 	float m_weight;
 	int tox1, tox2, toy1, toy2, size;
 	double rad, theta, theta1, theta2;
+	qreal angle, line_length, line_dx, line_dy;
 	bool m_Bezier, m_drawArrows, m_reciprocal;
 };
 
