@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
  
                          graph.h  -  description
@@ -55,7 +55,7 @@ class QDateTime;
 */
 
 typedef QList<Vertex*> Vertices;
-typedef map<int,int> imap_i;
+typedef map<long int,long int> imap_i;
 typedef map<int,float> imap_f;
 typedef QHash <QString, int> hash_si;
 
@@ -75,59 +75,61 @@ public slots:
 	void removeDummyNode(int);
 	
 	/** Slots to signals from GraphicsWidget and Parser*/
-	void createEdge (int, int, float, QString, bool, bool, bool);		//GW and Parser.
-	void createEdge (int, int, float, bool, bool, bool);				//GW
-	void createEdge (int, int);											//WebCrawler
-	void nodeMovement(int state, int type, int cW, int cH);			//Called by MW to start movement
+	void createEdge (int, int, float, QString, int, bool, bool);	//GW and Parser.
+	void createEdge (int, int, float, int, bool, bool);		//GW
+	void createEdge (int, int);					//WebCrawler
+	void nodeMovement(int state, int type, int cW, int cH);		//Called by MW to start movement
 
 	void slotSetEdgeVisibility( int, int, bool);
 	
 	//auxiliary createVertex functions
-	void createVertex(int i, QPointF p); 							//Called by GW
+	void createVertex(int i, QPointF p); 				//Called by GW
 	void createVertex(int i, int canvasWidth, int canvasHeight); 	//Called by MW
-	void createVertex(QString label, int i) ; 						//Called by WebCrawler
+	void createVertex(QString label, int i) ; 			//Called by WebCrawler
 	
 	/** Slots to signals from MainWindow */
-	void setCanvasDimensions(int w, int h);				
-	void filterEdgesByWeight (float, bool);				//Called by MW to filter edges over/under a weight
+	void setCanvasDimensions(int w, int h);
+	void filterOrphanVertices ( bool );		//Called by MW to filter orphan vertices
+	void filterEdgesByWeight (float, bool);		//Called by MW to filter edges over/under a weight
 	
 	void webCrawl( QString, int, int, bool);	//Called by MW to start a web crawler...
 	
 signals:
 	/** Signals to MainWindow */
 	void updateProgressDialog(int );
-	void graphChanged();								//call to update MW widgets
-	void selectedVertex(int);							//notifies MW who is the selected node
-	void signalFileType (int, QString, int,int, bool); //notifies MW what we have loaded.
-	void statusMessage (QString message);				//updates statusbar message
+	void graphChanged();					//call to update MW widgets
+	void selectedVertex(int);				//notifies MW who is the selected node
+
+	void signalFileType (int, QString, int,int, bool);	//notifies MW what we have loaded.
+	void statusMessage (QString message);			//updates statusbar message
 		
 	/** Signals to GraphicsWidget */
 	void drawNode( int ,int,  QString, QString, int, QString, QString, int, QPointF, QString, bool, bool, bool);	//call GW to draw a node
 	
-	void eraseNode (int);		//erase node from GW  
-	void drawEdge(int, int, float, bool, bool, QString, bool, bool);	//call GW to draw an edge
-	void eraseEdge(int, int);		//emited from removeEdge() to GW to clear the edge item.
-	void setEdgeVisibility ( int, int, bool); // emitted from each Vertex 
-	
-	void drawEdgeReciprocal(int, int);		//call GW to draw the edge as symmetric one
-	void addBackgrCircle(int, int, int);	//call GW to draw a circular layout line somewhere.
-	void addBackgrHLine (int);				//call GW to draw a horizontal layout line somewhere.
+	void eraseNode (long int);						//erase node from GW
+	void drawEdge(int, int, float, bool, bool, QString, bool);	//call GW to draw an edge
+	void eraseEdge(int, int);					//emited from removeEdge() to GW to clear the edge item.
+	void setEdgeVisibility ( int, int, bool);			// emitted from each Vertex
+	void setVertexVisibility(long int, bool);		//notifies GW to disable a node
+	void drawEdgeReciprocal(int, int);				//call GW to draw the edge as symmetric one
+	void addBackgrCircle(int, int, int);				//call GW to draw a circular layout line somewhere.
+	void addBackgrHLine (int);					//call GW to draw a horizontal layout line somewhere.
 	void moveNode(int, int, int);
 
 	
 public: 	
-	/**INIT AND CLEAR*/
-	Graph(); 				//Creates a new graph.
+	/* INIT AND CLEAR*/
+	Graph(); 			//Creates a new graph.
 	void clear();			//Clears m_graph 
-	~Graph();				//destroy
+	~Graph();			//destroy object
 
 	void setSocNetV_Version (QString ver) { VERSION = ver; }
 		
 	void setShowLabels(bool toggle);
 	void setShowNumbersInsideNodes(bool toggle);
 
-	/**FILES (READ AND WRITE)*/
-	bool loadGraph ( QString, bool,	int maxWidth, int maxHeight, int isListWithWeights	);	//Our almost universal network loader. :)
+	/*FILES (READ AND WRITE)*/
+	bool loadGraph ( QString, bool,	int maxWidth, int maxHeight, int format, int two_sm_mode);	//Our almost universal network loader. :)
 	
 	bool saveGraph( QString fileName, int fileType, 
 						QString networkName, int maxWidth, int maxHeight 
@@ -137,33 +139,33 @@ public:
 	bool saveGraphToDotFormat (QString fileName, QString networkName, int maxWidth, int maxHeight);
 	bool saveGraphToGraphMLFormat (QString fileName,QString networkName,  int maxWidth, int maxHeight);
 
-	/** VERTICES */
-	int lastVertexNumber();						//Returns the number of the last vertex
-	int firstVertexNumber();					//Returns the number of the first vertex
+	/* VERTICES */
+	int lastVertexNumber();				//Returns the number of the last vertex
+	int firstVertexNumber();			//Returns the number of the first vertex
 
-	int hasVertex(unsigned long  int );			//Checks if a vertex exists
-	int hasVertex(QString);						//Checks if a vertex with a label exists
-	void removeVertex (int );					//removes given vertex from m_graph
+	int hasVertex(long int );		//Checks if a vertex exists
+	int hasVertex(QString);				//Checks if a vertex with a label exists
+	void removeVertex (long int );			//removes given vertex from m_graph
 
-	void setInitVertexSize (int); 				//Changes the init size used in new vertices.
-	void setVertexSize(int v, int );			//Changes the size.of vertex v 
+	void setInitVertexSize (long int); 			//Changes the init size used in new vertices.
+	void setVertexSize(long int v, int );		//Changes the size.of vertex v
 
 	
-	void setInitVertexShape (QString); 			//Changes the init shape used in new vertices.
+	void setInitVertexShape (QString); 		//Changes the init shape used in new vertices.
 	void setVertexShape(int v, QString shape); 	//Changes the shape.of vertex v 
-	QString shape(int v);						//returns the shape of this vertex
+	QString shape(int v);				//returns the shape of this vertex
 
 	void setInitVertexColor (QString color);  	//Changes the init color used in new vertices
-	void setVertexColor(int v, QString color); 	//Changes the color.of vertex v 
+	void setVertexColor(long int v, QString color); 	//Changes the color.of vertex v
 
 
 	void setInitVertexNumberColor ( QString color);	//Changes the init number color in new vertices  
-	void setInitVertexNumberSize (int size);		//Changes the init number size in new vertices 
+	void setInitVertexNumberSize (int size);	//Changes the init number size in new vertices
 	
 	void setInitVertexLabelSize(int newSize);	//Changes the init size of new vertices labels
-	void setVertexLabelSize(int v, int newSize);//Changes the size of a vertex label
+	void setVertexLabelSize(int v, int newSize);	//Changes the size of a vertex label
 	
-	void setInitVertexLabelColor(QString color);//Changes the init color used by all new vertices' labels
+	void setInitVertexLabelColor(QString color);	//Changes the init color used by all new vertices' labels
 	void setVertexLabel(int v, QString label); 	//Changes the label.of vertex v
 	void setVertexLabelColor(int v1, QString color);  
 	QString label(int);			
@@ -171,72 +173,81 @@ public:
 
 	void updateVertCoords(int v, int x, int y);	 //Updates vertex v with coords x,y
 
-	int vertices() ;							//Returns the sum of vertices inside m_graph
+	int vertices() ;				//Returns the sum of vertices inside m_graph
 
-	int edgesFrom (int i) ;						//Returns the number of edges starting from v1 (outDegree)
-	int edgesTo (int i) ;						//Returns the number of edges ending to v1 (inDegree)  
+	int edgesFrom (int i) ;				//Returns the number of edges starting from v1 (outDegree)
+	int edgesTo (int i) ;				//Returns the number of edges ending to v1 (inDegree)
 
-	int verticesWithOutEdges();					//Returns the sum of vertices having outEdges
-	int verticesWithInEdges();					//Returns the sum of vertices having inEdges
-	int verticesWithReciprocalEdges();			//Returns the sum of vertices having reciprocal edges
+	int verticesWithOutEdges();			//Returns the sum of vertices having outEdges
+	int verticesWithInEdges();			//Returns the sum of vertices having inEdges
+	int verticesWithReciprocalEdges();		//Returns the sum of vertices having reciprocal edges
 
 
-	/**EDGES*/
-	float hasEdge (int v1, int v2);				//Checks if edge between v1 and v2 exists. Returns weight or -1
-	void removeEdge (int v1, int v2);			//removes the edge between v1 and v2
+	/* EDGES */
+	float hasEdge (int v1, int v2);			//Checks if edge between v1 and v2 exists. Returns weight or -1
+	void removeEdge (int v1, int v2);		//removes the edge between v1 and v2
 	
  
 	void setEdgeWeight (int v1, int v2, float w); 	//Sets the edge weight between v1 and v2
 	void setInitEdgeColor(QString);
 
-	void setEdgeColor(int s, int t, QString color);	//Changes the color of edge (s,t).
-	QString edgeColor (int s, int t); 				//Returns the edgeColor
+	void setEdgeColor(long int s, long int t, QString color);	//Changes the color of edge (s,t).
+	QString edgeColor (long int s, long int t); 		//Returns the edgeColor
 	 
-	int totalEdges ();							//Returns the sum of edges inside m_graph
+	int totalEdges ();				//Returns the sum of edges inside m_graph
 
-	float density();							//Returns ratio of present edges to total possible edges.
+	float density();				//Returns ratio of present edges to total possible edges.
 
-	bool symmetricEdge(int v1, int v2);			//Returns TRUE if (v1, v2) is symmetric.
-	bool isSymmetric();							//Returns TRUE if symmetricAdjacencyMatrix=TRUE
-	void symmetrize();							//Symmetrize all edges so that the network is undirected.
+	bool symmetricEdge(int v1, int v2);		//Returns TRUE if (v1, v2) is symmetric.
+	bool isSymmetric();				//Returns TRUE if symmetricAdjacencyMatrix=TRUE
+	void symmetrize();				//Symmetrize all edges so that the network is undirected.
+
+	void createAdjacencyMatrix(bool);
+	void invertAdjacencyMatrix();
 
 
-	/**PRINT OUT*/
+	/* PRINT OUT TO FILES*/
 	
 	void writeDataSetToFile(QString );			// Writes a known dataset to a file.
-	void writeAdjacencyMatrixTo(QTextStream& os);	 			//Exports the adjacency matrix to a given textstream
+	void writeAdjacencyMatrixTo(QTextStream& os);	 		//Exports the adjacency matrix to a given textstream
 	void writeAdjacencyMatrix(const char*, const char*);		//Writes the adjacency matrix to a given file.
+
+	void writeInvertAdjacencyMatrix(const char*,  const char*);
 	void writeDistanceMatrix(const char*, const char*, const char*);//Writes the distance matrix to a file
 	friend QTextStream& operator <<  (QTextStream& os, Graph& m);  	//
 
-	void writeCentralityInDegree(const QString, bool);				//Writes the in-degree centralities to a file
-	void writeCentralityOutDegree(const QString, const bool);		//Writes the out-degree centralities to a file
-	void writeCentralityCloseness(const QString, const bool);		//Writes the closeness centralities to a file
-	void writeCentralityBetweeness(const QString, const bool);		//Writes the betweeness centralities to a file
+	void writeCentralityInDegree(const QString, bool);		//Writes the in-degree centralities to a file
+	void writeCentralityOutDegree(const QString, const bool);	//Writes the out-degree centralities to a file
+	void writeCentralityCloseness(const QString, const bool);	//Writes the closeness centralities to a file
+	void writeCentralityBetweeness(const QString, const bool);	//Writes the betweeness centralities to a file
 	void writeCentralityGraph(const QString, const bool);		//Writes the Graph centralities to a file
+	void writeCentralityPower(const QString, const bool);		//Writes the Power centralities to a file
 	void writeCentralityStress(const QString, const bool);		//Writes the Stress centralities to a file	
-	void writeCentralityEccentricity(const QString, const bool);		//Writes the Eccentr centralities to a file
+	void writeCentralityEccentricity(const QString, const bool);	//Writes the Eccentr centralities to a file
+	void writeCentralityInformation(const QString);			//Writes the Information centralities to a file
 
 	void writeNumberOfCliques(const QString fileName, const bool considerWeights);
 	
-	void writeClusteringCoefficient(const QString, const bool);		//Writes the clustering coefficients to a file
+	void writeClusteringCoefficient(const QString, const bool);	//Writes the clustering coefficients to a file
 
 	void writeTriadCensus(const QString, const bool);		//Writes the triad census to a file	
 	
 
-	/**DISTANCES & CENTRALITIES*/
-	int distance( int, int);					//Returns the geodesic distance between two vertices
-	int diameter();								//Returns the diameter of the graph (maximum shortest path).
-	float averageGraphDistance();					//Returns the average shortest path length (average geodesic).
+	/* DISTANCES & CENTRALITIES */
+	int distance( int, int);		//Returns the geodesic distance between two vertices
+	int diameter();				//Returns the diameter of the graph (maximum shortest path).
+	float averageGraphDistance();		//Returns the average shortest path length (average geodesic).
 
-	void createDistanceMatrix(bool);			//Creates the distance matrix and calculates the centralities, if bool is true.
+	void createDistanceMatrix(bool);	//Creates the distance matrix and calculates the centralities, if bool is true.
 
-	void centralityInDegree(bool);				//Calculates the inDegree centrality of each vertex
-	void centralityOutDegree(bool);				//Calculates the outDegree centrality of each vertex
+	void centralityInDegree(bool);		//Calculates the inDegree centrality of each vertex
+	void centralityOutDegree(bool);		//Calculates the outDegree centrality of each vertex
+
+	void centralityInformation();
 
 	float numberOfTriples(int v1); 		//Returns the number of triples at vertex v1
 	float numberOfCliques(int v1);		//Calculates the number of cliques (triangles) of vertex v1
-	float numberOfCliques();			//Calculates the number of cliques (triangles) of the whole graph
+	float numberOfCliques();		//Calculates the number of cliques (triangles) of the whole graph
 	float clusteringCoefficient(int v1);	
 	float clusteringCoefficient ();
 	
@@ -245,7 +256,7 @@ public:
 //	void eccentr_JordanCenter(); 				// TODO
 
 
-	/**LAYOUTS*/	
+	/* LAYOUTS */
 	void layoutRandom(double maxWidth, double maxHeight);
 	void layoutRadialCentrality(double x0, double y0, double maxRadius, int CentralityType);
 	void layoutLayeredCentrality(double maxWidth, double maxHeight, int CentralityType);
@@ -268,14 +279,16 @@ public:
 	int factorial (int);				// for  (n 2)p edges calculation
 
 
-	/*
-	*   index stores the index of each vertex inside m_graph. It starts at zero (0).
-	*   This is crucial when we want to find the place of a vertex inside m_graph after adding or removing many vertices 
-	*/
-	imap_i index;			
-	/** maps have O(logN) lookup complexity
-		Consider using tr1::hashmap which has O(1) lookup, but this is not ISO C++ yet :(  
-	*/
+	/*  index stores the real position of each vertex inside m_graph. It starts at zero (0).
+	    We need to know the place of a vertex inside m_graph after adding or removing many vertices */
+	imap_i index;
+
+	// Stores the number of vertices at distance n from a given vertex
+	imap_i sizeOfNthOrderNeighborhood;
+
+	/* maps have O(logN) lookup complexity */
+	/* Consider using tr1::hashmap which has O(1) lookup, but this is not ISO C++ yet :(   */
+
 
 
 
@@ -300,7 +313,7 @@ private:
 						QPointF p, QString shape
 					);			// adds a vertex to m_graph
 						
-	void addEdge (int v1, int v2, float w, QString color, bool undirected); 		//adds an edge between v1 and v2, weight w, colored
+	void addEdge (int v1, int v2, float w, QString color, int reciprocal); 		//adds an edge between v1 and v2, weight w, colored
 
 	/** methods used by createDistanceMatrix()  */
 	void BFS(int, bool);									//Breadth-first search 
@@ -309,13 +322,13 @@ private:
 	void resolveClasses(float C, hash_si &discreteClasses, int &classes, int name);  	//helper
 
 	/** used in resolveClasses and createDistanceMatrix() */
-	hash_si discreteIDCs, discreteODCs, discreteCCs, discreteBCs, discreteSCs, discreteGCs, discreteECs;
+	hash_si discreteIDCs, discreteODCs, discreteCCs, discreteBCs, discreteSCs, discreteGCs, discreteECs, discretePCs, discreteICs;
 	
 	int *eccentricities;
 	bool calculatedIDC, calculatedODC, calculatedCentralities, dynamicMovement;
 	
 	QList<int>  triadTypeFreqs; 	//stores triad type frequencies
-	Matrix  TM, DM;
+	Matrix  TM, DM, sumM, invAM, AM, invM;
 	stack<int> Stack;
 
 	float meanDegree, varianceDegree;
@@ -324,22 +337,29 @@ private:
 	float minCC, maxCC, nomCC, denomCC, sumCC, groupCC, maxIndexCC;
 	float minBC, maxBC, nomBC, denomBC, sumBC, groupBC, maxIndexBC;
 	float minGC, maxGC, nomGC, denomGC, sumGC, groupGC, maxIndexGC;
+	float minPC, maxPC, sumPC, groupPC, maxIndexPC;
 	float minSC, maxSC, nomSC, denomSC, sumSC, groupSC, maxIndexSC;
 	float minEC, maxEC, nomEC, denomEC, sumEC, groupEC, maxIndexEC;
-	float minCLC, maxCLC, averageCLC;
+	float minIC, maxIC, nomIC, denomIC, sumIC, groupIC, maxIndexIC;
+	float minCLC, maxCLC, averageCLC, averageIC;
 	int maxNodeCLC, minNodeCLC;
 	int classesIDC, maxNodeIDC, minNodeIDC;
 	int classesODC, maxNodeODC, minNodeODC;
 	int classesCC, maxNodeCC, minNodeCC;
 	int classesBC, maxNodeBC, minNodeBC;
 	int classesGC, maxNodeGC, minNodeGC;
+	int classesPC, maxNodePC, minNodePC;
 	int classesSC, maxNodeSC, minNodeSC;
 	int classesEC, maxNodeEC, minNodeEC;
-
+	int classesIC, maxNodeIC, minNodeIC;
+	int sizeOfComponent;
 
 	/** General & initialisation variables */
 
-	int m_totalEdges, m_totalVertices, graphDiameter, initVertexSize, initVertexLabelSize, initVertexNumberSize;
+	long int m_totalEdges, m_totalVertices, graphDiameter, initVertexSize;
+	int initVertexLabelSize, initVertexNumberSize;
+
+	int isolatedVertices;
 	float averGraphDistance, nonZeroDistancesCounter;
 	int outEdgesVert, inEdgesVert, reciprocalEdgesVert;
 	int timerId,  layoutType, canvasWidth, canvasHeight;
@@ -354,3 +374,4 @@ private:
 };
 
 #endif
+
