@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
 
                         graphicswidget.cpp description
@@ -50,14 +50,10 @@ GraphicsWidget::GraphicsWidget( QGraphicsScene *sc, MainWindow* par)  : QGraphic
 	moving=0;
 	timerId=0;
 	layoutType=0;
-
 	m_nodeLabel="";
-	
 	zoomIndex=3;
-	
 	m_currentScaleFactor = 1;
 	m_currentRotationAngle = 0;
-	
 	markedNodeExists=false; //used in findNode()
 }
 
@@ -78,17 +74,14 @@ void GraphicsWidget::paintEvent ( QPaintEvent * event ){
 	Clears the scene 
 */
 void GraphicsWidget::clear() {
-	//qDebug("GW: clear()");
 	int i=0;
-	nodeVector.clear();
+	nodeHash.clear();
 	QList<QGraphicsItem *> allItems=scene()->items();
 	foreach (QGraphicsItem *item, allItems ) {
 		(item)->hide();
 		scene()->removeItem (item);
 		i++;
 	}
-	//qDebug("GW: Removed %i items from scene. Scene items now: %i ",i, scene()->items().size());
-	//qDebug("GW: items now: %i ", this->items().size());
 }
 
 
@@ -97,12 +90,10 @@ void GraphicsWidget::clear() {
 
 /**	
 	Adds a new node onto the scene 
-
 	Called from Graph::createVertex method when:
-			 we load files or
-			 the user presses "Add Node" button or
-			 the user double clicks (mouseDoubleClickEvent() calls Graph::createVertex
-
+		we load files or
+		the user presses "Add Node" button or
+		the user double clicks (mouseDoubleClickEvent() calls Graph::createVertex
 */
 void GraphicsWidget::drawNode(
 		int num, int size, QString nodeColor,
@@ -115,13 +106,11 @@ void GraphicsWidget::drawNode(
 	qDebug()<< "GW: drawNode(): drawing new node at: " 
 			<< p.x() << ", "<< p.y() ;
 
-
 	if (numberInsideNode)
 		size = size +3;
 	
 	Node *jim= new Node (
-			this,
-			num, size, nodeColor, shape,
+			this, num, size, nodeColor, shape,
 			numberInsideNode, m_labelDistance, m_numberDistance,
 			p
 			);
@@ -142,20 +131,15 @@ void GraphicsWidget::drawNode(
 	// drawing node number - label will be moved by the node movement (see last code line in this method)
 	if (numberInsideNode)
 		numberSize = size-2;
-		
+
 	NodeNumber *numberJim = new  NodeNumber ( jim, numberSize, QString::number(num), scene() );
 	numberJim -> setDefaultTextColor (numberColor);
 	
 	if (!showNumbers){
 		numberJim->hide();
 	}
-
-	//add the new node to a nodeVector to ease finding which node has a specific nodeNumber 
-	//The nodeVector is used in drawEdge() method
-	nodeVector.push_back(jim);
-	
-	//finally, move the node where it belongs!
-	jim -> setPos( p.x(), p.y());
+	nodeHash.insert(num, jim);//add new node to a container to ease finding, edge creation etc
+	jim -> setPos( p.x(), p.y());	//finally, move the node where it belongs!
 }
 
 
@@ -168,36 +152,20 @@ void GraphicsWidget::drawNode(
 	a) when we load a network file (check = FALSE)
 	b) when the user clicks on the AddLink button on the MW.
 */
-void GraphicsWidget::drawEdge(int i, int j, float weight, bool reciprocal, bool drawArrows, QString color, bool bezier, bool check){
-	qDebug()<<"GW: drawEdge ("<< i<< ","<< j<< ") with weight "<<weight << " - nodeVector reports "<< nodeVector.size()<<" nodes.";
-	if (check) {
-		vector<Node*>::iterator it;
-		int index=1;
-		for ( it=nodeVector.begin() ; it < nodeVector.end(); it++ ) {
-			if ((*it)->nodeNumber() == i ) {		
-				break;
-			}
-			index++;
-		}
-		i=index;
-		index=1;
-		for ( it=nodeVector.begin() ; it < nodeVector.end(); it++ ) {
-			if ((*it)->nodeNumber() == j ) {		
-				break;
-			}
-			index++;
-		}
-		j=index;
-
-	}
+void GraphicsWidget::drawEdge(int i, int j, float weight, bool reciprocal, bool drawArrows, QString color, bool bezier){
+	qDebug()<<"GW: drawEdge ("<< i<< ","<< j<< ") with weight "<<weight << " - nodeHash reports "<< nodeHash.size()<<" nodes.";
 	if (i == j ) {
 		bezier = true;		
 	}
-
-	qDebug()<< "GW: drawEdge() drawing edge now!"<< " From node "<<  nodeVector.at(i-1)->nodeNumber()<< " to "<<  nodeVector.at(j-1)->nodeNumber() << " weight "<< weight << " nodesize "<<  m_nodeSize << " edgecolor "<< color ;
-	Edge *edge=new Edge (this, nodeVector.at(i-1), nodeVector.at(j-1), weight, m_nodeSize, color, reciprocal, drawArrows, bezier);
+	qDebug()<< "GW: drawEdge() drawing edge now!"<< " From node "
+			<<  nodeHash.value(i)->nodeNumber()<< " to node "
+			<<  nodeHash.value(j)->nodeNumber() << " weight "
+			<< weight << " nodesize "
+			<<  m_nodeSize << " edgecolor "<< color ;
+	Edge *edge=new Edge (this, nodeHash.value(i), nodeHash.value(j), weight,
+			     m_nodeSize, color, reciprocal, drawArrows, bezier);
 	edge -> setZValue(253);		//Edges have lower z than nodes. Nodes always appear above edges.
-	//ssetBoundingRegionGranularity() is a real headache. Keep it here so that it doesnt interfere with dashed lines.
+	// Keep it here so that it doesnt interfere with dashed lines.
 	edge->setBoundingRegionGranularity(0.05);	// Slows down the universe...Keep it 0.05...
 	//edge->setCacheMode (QGraphicsItem::DeviceCoordinateCache);  //Also slows down the universe...
 
@@ -206,8 +174,9 @@ void GraphicsWidget::drawEdge(int i, int j, float weight, bool reciprocal, bool
 	edgesMap [edgeName] =  edge;
 
 	qDebug()<< "GW: drawNode(): drawing edge weight number...";
-	double x = ( (nodeVector.at(i-1))->x() + (nodeVector.at(j-1))->x() ) / 2.0;
-	double y = ( (nodeVector.at(i-1))->y() + (nodeVector.at(j-1))->y() ) / 2.0;
+	double x = ( (nodeHash.value(i))->x() + (nodeHash.value(j))->x() ) / 2.0;
+	double y = ( (nodeHash.value(i))->y() + (nodeHash.value(j))->y() ) / 2.0;
+
 	EdgeWeight *edgeWeight = new  EdgeWeight (edge, 7, QString::number(weight), scene() );
 	edgeWeight-> setPos(x,y);
 	edgeWeight-> setDefaultTextColor (color);
@@ -313,23 +282,22 @@ void GraphicsWidget::nodeMoved(int number, int x, int y){
 */
 void GraphicsWidget::moveNode(int number, int x, int y){
 	qDebug ("GW: updateNode() %i with %i, %i", number, x,y);
-	nodeVector.at(number-1)->setPos(x,y);
-	if (nodeVector.at(number-1)->nodeNumber()!=number) qDebug("ERRRRRRRRRRRRRRRRRRROOOOR");
+	nodeHash.value(number)->setPos(x,y);
 }
 
 
 /**
 	Called from Graph signal eraseNode(int) 
 */
-void GraphicsWidget::eraseNode(int doomedJim){
-	qDebug("GW: Deleting node %i ", doomedJim);
+void GraphicsWidget::eraseNode(long int doomedJim){
+	qDebug() << "GW: Deleting node "<< doomedJim;
 	QList<QGraphicsItem *> list=scene()->items();
 	qDebug("GW: Scene items= %i - View items : %i",scene()->items().size(), items().size());
 	for (QList<QGraphicsItem *>::iterator it=list.begin(); it!=list.end(); it++) {
 		if ( (*it)->type()==TypeNode) {
 			Node *jim=(Node*) (*it);
 			if ( jim->nodeNumber()==doomedJim)	{
-				qDebug("GW: found doomedJim %i. Demanding node->die() :)", jim->nodeNumber());
+				qDebug() << "GW: found doomedJim " <<  jim->nodeNumber() << " Demanding node->die() :)" ;
 				jim->die();
 				delete *it;
 				break;
@@ -337,7 +305,6 @@ void GraphicsWidget::eraseNode(int doomedJim){
 		}
 	}
 	qDebug("GW: Scene items now= %i - View items now= %i ", scene()->items().size(), items().size() );
-
 }
 
 
@@ -368,26 +335,23 @@ void GraphicsWidget::eraseEdge(int sourceNode, int targetNode){
 
 
 /** 
-	Called from Node::die() to removeItem from nodeVector...
+	Called from Node::die() to removeItem from nodeHash...
 */
 void GraphicsWidget::removeItem( Node *node){
 	vector<Node*>::iterator it;
-	int i=0;
-	for ( it=nodeVector.begin() ; it < nodeVector.end(); it++ ) {
-		if ((*it)->nodeNumber() == node->nodeNumber()) {		
-			break;
-		}
-		i++;
+	long int i=node->nodeNumber();
+	foreach ( Node *candidate, nodeHash) {
+		if ( candidate->nodeNumber() == i )
+			nodeHash.remove( i );
 	}
-	nodeVector.erase(nodeVector.begin()+i);
 	node->deleteLater ();
-	qDebug("GW items now: %i ", items().size());
+	qDebug() << "GW items now:  " << items().size();
 }
 
 
 
 
-/** Called from Node::die() to removeItem from nodeVector... */
+/** Called from Node::die() to remove Edge edge ... */
 void GraphicsWidget::removeItem( Edge * edge){
 	edge->remove();
 	delete (edge);
@@ -395,9 +359,9 @@ void GraphicsWidget::removeItem( Edge * edge){
 
 
 void GraphicsWidget::removeItem( NodeLabel *nodeLabel){
-	qDebug("GW items now: %i ", items().size());
+	qDebug() << "GW items now:  " << items().size();
 	delete (nodeLabel);
-	qDebug("GW items now: %i ", items().size());
+	qDebug() << "GW items now:  " << items().size();
 }
 
 
@@ -437,7 +401,7 @@ void GraphicsWidget::setInitLinkColor(QString color){
 	Sets the color of an node.
 	Called from MW when the user changes the color of a node (right-clicking).
 */
-bool GraphicsWidget::setNodeColor(int nodeNumber, QString color){
+bool GraphicsWidget::setNodeColor(long int nodeNumber, QString color){
 	QList<QGraphicsItem *> list=scene()->items();
 	for (QList<QGraphicsItem *>::iterator it=list.begin(); it!= list.end() ; it++){
 		if ( (*it)->type()==TypeNode) {
@@ -458,13 +422,13 @@ bool GraphicsWidget::setNodeColor(int nodeNumber, QString color){
 */
 void   GraphicsWidget::setNumbersInsideNodes(bool numIn){
 	qDebug("GW setting initNumberDistance");
-	foreach (Node *node, nodeVector) {
-		qDebug("GW: Number foundMovin it now...");
-		node->setNumberInside(numIn);
+	foreach ( Node *m_node, nodeHash) {
+		m_node->setNumberInside(numIn);
 		if (numIn)
 			this->setInitNodeSize(m_nodeSize+2);
-		else 
+		else
 			this->setInitNodeSize(m_nodeSize-2);
+
 	}
 }
 
@@ -574,56 +538,68 @@ void GraphicsWidget::setEdgeVisibility(int source, int target, bool visible){
 }
 
 
-/*
- *  OBSOLETE?
- */
-bool GraphicsWidget::hasEdge (int source, int target){
-	QString edgeName = QString::number( source ) + QString(">")+ QString::number( target );
-	if  ( edgesMap.contains (edgeName) ){
-		qDebug() << "GW: DOES hasEdge() from " << source << " to " << target ;
-		return true;
-	}
-	else {
-		qDebug() << "GW: DOES NOT hasEdge() from " << source << " to " << target ;
-		return false;
-	}
-		
-}
 
-
-
-// unused
-Node* GraphicsWidget::hasNode( int number ){
-	vector<Node*>::iterator it;
-	for ( it=nodeVector.begin() ; it < nodeVector.end(); it++ ) {
-		if ((*it)->nodeNumber() == number ) {
-			qDebug() << "GW: hasNode(): Node numbered " << number << " found!";
-			markedNodeExists=true;
-			return (*it);	
-			break;
+/**
+*	Changes the visibility of a  Node
+*/
+void GraphicsWidget::setNodeVisibility(long int number, bool visible){
+    qDebug() << "GW: setNodeVisibility() for "<< number;
+    QList<QGraphicsItem *> list = scene()->items();
+    for (QList<QGraphicsItem *>::iterator item=list.begin();item!=list.end(); item++) {
+	if ( (*item)->type() == TypeNode){
+	    if ( Node *node = qgraphicsitem_cast<Node *>(*item) )
+		if ( node->nodeNumber() == number ) {
+		    if (visible){
+			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Will be visible now...";
+			(*item)->show();
+		    }
+		    else {
+			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Invisible now...";
+			(*item)->hide();
+		    }
 		}
-	}
-	return markedNode;	//dummy return. We check markedNodeExists flag first...
+	    }
+    }
+
+//	qDebug() << "GW: setNodeVisibility() for "<< number;
+//	foreach ( Node *candidate, nodeHash) {
+//		if (candidate->nodeNumber() == number ) {
+//		    if (visible) {
+//			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Will be visible now...";
+//			candidate->show();
+//			candidate->update();
+//		    }
+//		    else{
+//			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Invisible now...";
+//			candidate->hide();
+//		    }
+//
+//			break;
+//		}
+//
+//	}
 }
 
 
 
+
 /*
  * Used by findNode. 
- * Returns, if any, Node with label or number 'text'
+ * Returns, if found, the node with label or number 'text'
  */
 Node* GraphicsWidget::hasNode( QString text ){
 	vector<Node*>::iterator it;
 	bool ok = false;
-	for ( it=nodeVector.begin() ; it < nodeVector.end(); it++ ) {
-		if ( 	(*it)->nodeNumber()==text.toInt(&ok, 10)  || 
-				(*it)->labelText().contains (text, Qt::CaseInsensitive)
-			 ) {
+	foreach ( Node *candidate, nodeHash) {
+		if ( 	candidate->nodeNumber()==text.toInt(&ok, 10)  ||
+			candidate->labelText().contains (text, Qt::CaseInsensitive)
+			) {
 			qDebug() << "GW: hasNode(): Node " << text << " found!";
 			markedNodeExists=true;
-			return (*it);	
+			return candidate;
 			break;
 		}
+
 	}
 	return markedNode;	//dummy return. We check markedNodeExists flag first...
 }
@@ -683,19 +659,33 @@ void GraphicsWidget::addBackgrHLine( int y0){
 	circ->show();
 }
 
-void GraphicsWidget::clearBackgrCircles(){
-	QList<QGraphicsItem *> allItems=scene()->items();
-	foreach (QGraphicsItem *item, allItems ) {
-		if ( (item)->type()==TypeBackgrCircle) {
-			qDebug("GW: Deleting a background Circle now...");
-			(item)->hide();
-			delete (item);
+
+/**
+*	Removes all items of certain type (i.e. number, label, edge, etc)
+*/
+void GraphicsWidget::removeAllItems(int type){
+	qDebug()<< "GW: removeAllItems";
+	QList<QGraphicsItem *> list = scene()->items();
+	for (QList<QGraphicsItem *>::iterator item=list.begin();item!=list.end(); item++) {
+		if ( (*item)->type() == type){
+			BackgrCircle *bgcircle = qgraphicsitem_cast<BackgrCircle *>  (*item);
+			qDebug()<< "GW: removeAllItems - located element";
+			bgcircle->die();
+			bgcircle->deleteLater ();
+			delete *item;
 		}
 	}
 }
 
 
 
+void GraphicsWidget::clearBackgrCircles(){
+	qDebug()<< "GW: clearBackgrCircles";
+	this->removeAllItems(TypeBackgrCircle);
+}
+
+
+
 
 
 /** 	
@@ -718,8 +708,8 @@ void GraphicsWidget::mouseDoubleClickEvent ( QMouseEvent * e ) {
 
 	QPointF p = mapToScene(e->pos());
 	qDebug()<< " GW: mouseDoubleClickEvent():double click detected on empty space. "
-	       << " Emitting signal to MW to create a new vertex in graph. e->pos() "
-	       << e->pos().x() << ", "<< e->pos().y() << ", "<< p.x() << ", " <<p.y();
+		  << " Emitting signal to MW to create a new vertex in graph. e->pos() "
+		  << e->pos().x() << ", "<< e->pos().y() << ", "<< p.x() << ", " <<p.y();
 	emit userDoubleClicked(-1, p);
 	qDebug("GW: mouseDoubleClickEvent(): Scene and GW items now: %i and %i. Emitting Changed() signal... ", scene()->items().size(), items().size());
 }
@@ -817,7 +807,7 @@ void GraphicsWidget::openEdgeContextMenu(){
 */
 void GraphicsWidget::wheelEvent(QWheelEvent *e) {
 	qDebug("GW: Mouse wheel event");
-	qDebug("GW: delta = %i", e->delta());	
+	qDebug() << "GW: delta = " << e->delta();
   	float m_scale = e->delta() / qreal(600);
 	qDebug("GW: m_scale = %f", m_scale);	
 	if ( m_scale > 0)
