@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
  
                          graphicswidget.h  -  description
@@ -43,7 +43,7 @@ class BackgrCircle;
 class EdgeWeight;
 
 typedef QMap<QString, Edge*> StringToEdgeMap;
-
+typedef QHash <long int, Node*> hash_in;
 
 class GraphicsWidget : public QGraphicsView {
 	Q_OBJECT
@@ -53,7 +53,7 @@ public:
 	void clear();
 
 	Node* hasNode(QString text);
-	Node* hasNode(int number);
+//	Node* hasNode(int number);
 	bool setMarkedNode(QString text);
 	
 	void removeItem(Edge*);
@@ -70,17 +70,15 @@ public:
 
 	void setNumbersInsideNodes(bool);
 	
-	bool setNodeColor(int, QString);
+	bool setNodeColor(long int, QString);
 	
 	bool setEdgeColor(int, int, QString);
 	
 	bool setEdgeWeight(int, int, float);
 	
 	void setAllItemsVisibility(int, bool);
-
-	bool hasEdge (int source, int target);
-	
 	
+	void removeAllItems(int);
 protected:
 	void wheelEvent(QWheelEvent *event);
 	void mouseDoubleClickEvent ( QMouseEvent * e );
@@ -97,11 +95,11 @@ public slots:
 					QString nodeShape, 
 					bool showLabels, bool labelIn, bool showNumbers
 					);
-	void eraseNode(int doomedJim);
-	void drawEdge(int, int, float, bool, bool, QString, bool, bool);
+	void eraseNode(long int doomedJim);
+	void drawEdge(int, int, float, bool, bool, QString, bool);
 	void eraseEdge(int, int);
 	void setEdgeVisibility ( int, int, bool);
-
+	void setNodeVisibility(long int, bool );	//Called from Graph via MW
 	
 	void nodeClicked(Node *);
 	void edgeClicked(Edge *);
@@ -133,6 +131,8 @@ signals:
 	void zoomChanged(int);
 	
 private:
+	hash_in nodeHash;			//This is used in drawEdge() method
+	StringToEdgeMap edgesMap;
 	int timerId,  layoutType, m_nodeSize, m_numberDistance, m_labelDistance;
 	double m_currentScaleFactor;
 	int m_currentRotationAngle;
@@ -142,8 +142,7 @@ private:
 	QGraphicsItem *moving;
 	QPointF startPoint, endPoint;
 	Node *firstNode, *secondNode, *markedNode, *tempNode ;
-	vector<Node*> nodeVector;					//used by addEdge() method
-	StringToEdgeMap edgesMap;
+
 };
 
 #endif
