@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
  
                          mainwindow.h  -  description
@@ -41,7 +41,7 @@
 #include "datasetselectdialog.h"
 
 
-static const QString VERSION="0.81";
+static const QString VERSION="0.90";
 
 /**
   * This Class is the base class. It sets up the main
@@ -122,7 +122,7 @@ public slots:
 	void slotImportGML();
 	void slotImportDL();
 	void slotImportEdgeList();
-
+	void slotImportTwoModeSM();
 	void slotFileSave();
 	void slotFileSaveAs();
 	void slotFileClose();
@@ -140,7 +140,7 @@ public slots:
 	void slotViewNetworkFile();
 	void slotViewAdjacencyMatrix();
 	void slotShowDataSetSelectDialog();
-		void slotRecreateDataSet(QString);
+	void slotRecreateDataSet(QString);
 	void slotCreateRandomNetErdos();
 	void slotCreateSameDegreeRandomNetwork();
 	void slotCreateGaussianRandomNetwork();
@@ -167,6 +167,7 @@ public slots:
 	void slotChangeLinkColor();
 	void slotChangeLinkWeight();
 	void slotFilterNodes();
+	void slotFilterOrphanNodes();
 	void slotShowFilterEdgesDialog();
 	void slotTransformNodes2Links();
 	void slotSymmetrize();
@@ -180,7 +181,8 @@ public slots:
 	void slotLayoutRadialCentralityInDegree();
 	void slotLayoutRadialCentralityCloseness();
 	void slotLayoutRadialCentralityBetweeness();
-	void slotLayoutRadialCentralityInformational();
+        void slotLayoutRadialCentralityPower();
+        void slotLayoutRadialCentralityInformation();
 	void slotLayoutRadialCentralityStress();
 	void slotLayoutRadialCentralityGraph();
 	void slotLayoutRadialCentralityEccentr();
@@ -188,7 +190,7 @@ public slots:
 	void slotLayoutLayeredCentralityOutDegree();
 	void slotLayoutLayeredCentralityCloseness();
 	void slotLayoutLayeredCentralityBetweeness();
-	void slotLayoutLayeredCentralityInformational();
+        void slotLayoutLayeredCentralityInformation();
 	
 	void slotLayoutSpringEmbedder();
 	void layoutSpringEmbedder (int);
@@ -207,15 +209,18 @@ public slots:
 	void slotClusteringCoefficient();
 	void slotTriadCensus();
 	void slotCheckSymmetry();
+	void slotInvertAdjMatrix();
 
 	void slotCentralityOutDegree();
 	void slotCentralityInDegree();
 	void slotCentralityCloseness();
 	void slotCentralityBetweeness();
-	void slotCentralityInformational();
+	void slotCentralityInformation();
 	void slotCentralityGraph();
 	void slotCentralityStress();
+	void slotCentralityPower();
 	void slotCentralityEccentricity();
+
 	//OPTIONS MENU
 	void slotDisplayNodeNumbers(bool toggle);
 	void slotDisplayNodeLabels(bool toggle);
@@ -235,6 +240,7 @@ public slots:
 	void slotAllLinksColor();
 	void slotAllNumbersColor();
 	void slotAllLabelsColor();
+
 	//VIEW MENU
 	void slotAntialiasing(bool );
 	void slotShowProgressBar(bool toggle);
@@ -324,7 +330,7 @@ private:
 
 	QAction *fileNew, *fileOpen, *fileSave, *fileSaveAs,*fileClose, *printNetwork,*fileQuit;
 	QAction *exportBMP, *exportPNG, *exportPajek, *exportPDF, *exportDL, *exportGW, *exportSM, *exportList;
-	QAction *importPajek,*importSM, *importList, *importDot , *importDL; 
+	QAction *importPajek,*importSM, *importList,  *importDot , *importDL, *importTwoModeSM;
 	
 	QAction *viewNetworkFileAct, *openTextEditorAct, *viewSociomatrixAct, *recreateDataSetAct; 
 	
@@ -336,20 +342,20 @@ private:
 	QAction *changeLabelsSizeAct, *changeAllNodesSizeAct, *changeAllNodesShapeAct;
 	QAction *changeNodeBoxAct, *changeNodeCircleAct, *changeNodeTriangleAct, *changeNodeDiamondAct, *changeNodeEllipseAct;
 	QAction *changeLinkLabelAct, *changeLinkColorAct, *changeLinkWeightAct;
-	QAction *filterNodesAct, *filterEdgesAct, *transformNodes2LinksAct, *symmetrizeAct;
+	QAction *filterNodesAct, *filterOrphanNodesAct, *filterEdgesAct, *transformNodes2LinksAct, *symmetrizeAct;
 	QAction *changeBackColorAct, *changeAllNodesColorAct, *changeAllLinksColorAct, *changeAllNumbersColorAct, *changeAllLabelsColorAct;
 	QAction *drawLinksWeightsAct, *displayLinksWeightNumbersAct, *displayLinksAct, *displayLinksArrowsAct, *drawLinksBezier;
 	QAction *backgroundImageAct, *viewToolBar, *viewStatusBar, *helpAboutApp, *helpAboutQt, *helpApp, *tipsApp;
 	QAction *netDensity, *symmetryAct,   *graphDistanceAct, *averGraphDistanceAct, *distanceMatrixAct, *diameterAct;
-	QAction *cliquesAct, *clusteringCoefAct, *triadCensusAct;
-	QAction *cOutDegreeAct, *cInDegreeAct, *cClosenessAct, *cBetweenessAct, *cInformationalAct, *cGraphAct, *cStressAct, *cEccentAct;
+	QAction *cliquesAct, *clusteringCoefAct, *triadCensusAct, *invertAdjMatrixAct;
+	QAction *cOutDegreeAct, *cInDegreeAct, *cClosenessAct, *cBetweenessAct, *cInformationAct, *cGraphAct, *cStressAct, *cPowerAct, *cEccentAct;
 	QAction *randLayoutAct, *randCircleLayoutAct, *circleOutDegreeLayoutAct, *circleInDegreeLayoutAct, *circleClosenessLayoutAct;
 	QAction *antialiasingAct;
 	QAction *webCrawlerAct;
 
-	QAction *circleStressLayoutAct, *circleGraphLayoutAct,*circleClearBackgrCirclesAct, *circleEccentrLayoutAct;
-	QAction *circleBetweenessLayoutAct, *circleInformationalLayoutAct, *levelClosenessLayoutAct;
-	QAction *levelInDegreeLayoutAct, *levelOutDegreeLayoutAct, *levelBetweenessLayoutAct, *levelInformationalLayoutAct;
+        QAction *circleStressLayoutAct, *circleGraphLayoutAct,*circleClearBackgrCirclesAct, *circleEccentrLayoutAct, *circlePowerLayoutAct;
+        QAction *circleBetweenessLayoutAct, *circleInformationLayoutAct, *levelClosenessLayoutAct;
+        QAction *levelInDegreeLayoutAct, *levelOutDegreeLayoutAct, *levelBetweenessLayoutAct, *levelInformationLayoutAct;
 	QAction *strongColorationAct, *regularColorationAct, *showProgressBarAct, *printDebugAct;
 	QAction *springLayoutAct, *FRLayoutAct, *nodeSizeProportionalOutDegreeAct,  *nodeSizeProportionalInDegreeAct;
 	QAction *zoomInAct, *zoomOutAct ;
@@ -372,10 +378,8 @@ private:
 	QColor initBackgroundColor;
 	QPointF cursorPosGW;	//Carries the position of the cursor in graphicsWidget coordinates
 	QLCDNumber  *inLinksLCD, *outLinksLCD , *selectedNodeLCD, *clucofLCD;
-	QLCDNumber *nodesLCD, *edgesLCD, *densityLCD, *outLinkedNodesLCD, *inLinkedNodesLCD, *reciprocalLinkedNodesLCD;
+	QLCDNumber *nodesLCD, *edgesLCD, *densityLCD;
 
-
-	
 	QDateTime actualDateTime, actualDate, actualTime;
 	QTime eTime;     //used  to time algorithms.	
 };
