@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
 
                         node.cpp  -  description
@@ -31,6 +31,7 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QStyleOption>
 #include <QPainter>
+#include <QtGlobal>  //for QT_VERSION
 #include <QDebug>
 #include "graphicswidget.h"
 #include "edge.h"
@@ -46,16 +47,17 @@ Node::Node( GraphicsWidget* gw, int num, int size,
 	Q_UNUSED(p);
 	graphicsWidget->scene()->addItem(this); //Without this nodes don't appear on the screen...
 
-
+//ItemSendsGeometryChanges  introduced in Qt 4.6...
 #if QT_VERSION >= 0x040600
-	setFlags(ItemSendsGeometryChanges | ItemIsSelectable | ItemIsMovable); //ItemSendsGeometryChanges  introduced in Qt 4.6...
+	setFlags(ItemSendsGeometryChanges | ItemIsSelectable | ItemIsMovable);
+	setCacheMode(QGraphicsItem::DeviceCoordinateCache); //QT < 4.6 if a cache mode is set, nodes do not respond to hover events
+
 #else
-	setFlags(ItemIsSelectable | ItemIsMovable); //Without this, the node cannot move nor be selected ...
+	setFlags(ItemIsSelectable | ItemIsMovable ); //Without this, the node cannot move nor be selected ...
+	setCacheMode(QGraphicsItem::NoCache); //QT < 4.6 if a cache mode is set, nodes do not respond to hover events
 #endif
-
-
-	setCacheMode(DeviceCoordinateCache);
 	setAcceptsHoverEvents(true);
+
 	m_num=num;
 	m_size=size;
 	m_hasLabel=false;
@@ -72,13 +74,6 @@ Node::Node( GraphicsWidget* gw, int num, int size,
 			<< this->x()<<", "<<this->y()
 			<< " Will move at: "<< p.x()<<", "<<p.y();;
 
-
-
-/*	connect (this, SIGNAL(nodeClicked(Node*)),graphicsWidget , SLOT(nodeClicked(Node*)));
-	connect (this, SIGNAL(startNodeMovement(int)), graphicsWidget, SLOT(startNodeMovement(int)));
-	connect (this, SIGNAL(openNodeContextMenu()), graphicsWidget, SLOT(openNodeContextMenu()));
-	connect (this, SIGNAL(startEdge(Node*)),graphicsWidget, SLOT(startEdge(Node*)));*/
-	//qDebug("Node() - End of constructor");
 } 
 
 /** 
@@ -378,9 +373,8 @@ void Node::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWid
 /** Removes the node */
 
 void Node::die() {
-	qDebug ("Node: Remove() node= %i", nodeNumber());
-/*	emit removeOutEdge();
-	emit removeInEdge();*/
+	qDebug () << "Node: die() node= "<< nodeNumber();
+
 	foreach (Edge *edge, inEdgeList) {
 		qDebug("Node: removing edges in inEdgeList");
 		edge->remove();
@@ -429,7 +423,7 @@ void Node::setNumberInside (bool numIn){
 						m_number -> setZValue(254);
 						m_number -> setPos( myPos.x()+m_nd, myPos.y() );
 					}	 
-					else { 				//move it inside node
+					else { 		//move it inside node
 						this->setSize(m_size+2); //increase size to display nicely the number  
 						m_number -> setZValue(255);
 						m_number->setPos( myPos.x() - m_size-2, myPos.y() - m_size-2 );
@@ -448,35 +442,36 @@ QVariant Node::itemChange(GraphicsItemChange change, const QVariant &value) {
 	QPointF newPos = value.toPointF();
 
 	switch (change) {
-	case ItemPositionHasChanged :
-		{  //ItemPositionChange
-			// 	emit adjustOutEdge();
-			// 	emit adjustInEdge();
+		case ItemPositionHasChanged :
+		{
 			foreach (Edge *edge, inEdgeList)  //Move each inEdge of this node
 				edge->adjust();
 			foreach (Edge *edge, outEdgeList) //Move each outEdge of this node
 				edge->adjust();
 			//Move its graphic number
-			if ( m_hasNumber ) 
+			if ( m_hasNumber )
 			{
 				if (!m_isNumberInside) 	{ //move it outside
 					m_number -> setZValue(254);
-					m_number -> setPos( newPos.x()+m_size+m_nd, newPos.y());
-									}
+					m_number -> setPos( m_size+m_nd, 0);
+				}
 				else { 	//move it inside node
 					m_number -> setZValue(255);
-					m_number -> setPos( newPos.x() - m_size-2, newPos.y() - m_size-2 );
+					m_number -> setPos(  - m_size, - m_size-3);
 				}
 			}
 			if (m_hasLabel) {
-				m_label->setPos( newPos.x()-2, newPos.y()+m_ld+m_size);
+				m_label->setPos( -2, m_ld+m_size);
 			}
 			if ( newPos.x() !=0 && newPos.y() != 0 ){
-				graphicsWidget->nodeMoved(nodeNumber(), (int) newPos.x(), (int) newPos.y());	
+				graphicsWidget->nodeMoved(nodeNumber(), (int) newPos.x(), (int) newPos.y());
 			}
 			else qDebug()<<  "Node: ItemChange():  Not emitting nodeMoved. Node "<< nodeNumber()<<" is at 0,0";
 			break;
-		} 
+		}
+		case ItemEnabledHasChanged:{
+			return 0;
+		}
 	case ItemVisibleChange:
 		{
 			return 0;
@@ -518,24 +513,21 @@ void Node::mousePressEvent(QGraphicsSceneMouseEvent *event) {
 
 
 void Node::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
-    update();
-    QGraphicsItem::mouseReleaseEvent(event);
+	update();
+	QGraphicsItem::mouseReleaseEvent(event);
 }
 
 
 
 void Node::addInLink( Edge *edge ) {
-	qDebug("Node:  %i addInLink()", m_num);
-/*	connect (this, SIGNAL(adjustInEdge()),edge, SLOT(adjust()));
-	connect (this, SIGNAL(removeInEdge()),edge, SLOT(remove()));*/
+	qDebug() << "Node:  addInLink() for "<<  m_num;
 	inEdgeList.push_back( edge); 
 	//qDebug ("Node:  %i inEdgeList has now %i edges", m_num, inEdgeList.size());
-
 }
 
 
 void Node::deleteInLink( Edge *link ){
-	qDebug ("Node:  %i inEdgeList deleting link", m_num);
+	qDebug () << "Node:  deleteInLink for "<< m_num;
 	//qDebug ("Node: %i inEdgeList has %i edges", m_num, inEdgeList.size());
 	inEdgeList.remove( link);
 	//qDebug ("Node:  %i inEdgeList has now %i edges", m_num, inEdgeList.size());
@@ -545,9 +537,6 @@ void Node::deleteInLink( Edge *link ){
 
 void Node::addOutLink( Edge *edge ) {
 	qDebug("Node: addOutLink()");
-
-/*	connect (this, SIGNAL(adjustOutEdge()),edge, SLOT(adjust()));
-	connect (this, SIGNAL(removeOutEdge()),edge, SLOT(remove()));*/
 	outEdgeList.push_back( edge); 
 //	qDebug ("Node: outEdgeList has now %i edges", outEdgeList.size());
 }
@@ -555,7 +544,7 @@ void Node::addOutLink( Edge *edge ) {
 
 
 void Node::deleteOutLink(Edge *link){
-	qDebug ("Node: %i outEdgeList deleting link", m_num);
+	qDebug () << "Node: deleteOutLink() from " <<  m_num;
 //	qDebug ("Node: %i outEdgeList has %i edges", m_num, outEdgeList.size());
 	outEdgeList.remove( link);
 //	qDebug ("Node: %i outEdgeList has now %i edges", m_num, outEdgeList.size());
