@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
  
                          node.h  -  description
@@ -53,7 +53,8 @@ static const int TypeNode = QGraphicsItem::UserType+1;
 //
 
 class Node :  public QObject,  public QGraphicsItem {
-  Q_OBJECT
+	Q_OBJECT
+	Q_INTERFACES (QGraphicsItem)
 
 public:
 	Node(GraphicsWidget*, int num, int size, QString col, QString shape, bool, int, int, QPointF p) ;
@@ -71,7 +72,7 @@ public:
 	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
 
 	void die(); 
-	int nodeNumber() {return m_num;}
+	long int nodeNumber() {return m_num;}
 
 	void setSize(int);
 	int size();
@@ -121,7 +122,8 @@ private:
 	QPainterPath *m_path;
 	QPointF newPos;
 	QPolygon *m_poly_t, *m_poly_d;
-	int m_num, m_size, m_nd, m_ld;
+	int  m_size, m_nd, m_ld;
+	long int m_num;
 	QString  m_shape,  m_col_str, m_labelIn;
 	QColor m_col;
 	bool m_hasNumber, m_hasLabel, m_isNumberInside;
