@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
  
                          parser.cpp  -  description
@@ -42,7 +42,8 @@ bool Parser::load(QString fn, int iNS, QString iNC, QString iNSh,
 					QString iNLC, int iNLS , 
 					QString iEC, 
 					int width, int height,
-					int fFormat
+					int fFormat,
+					int sm_mode
 					)
 {
 	qDebug("Parser: load()");
@@ -56,7 +57,7 @@ bool Parser::load(QString fn, int iNS, QString iNC, QString iNSh,
 	
 	initEdgeColor=iEC;
 	
-	undirected=FALSE; arrows=FALSE; bezier=FALSE;
+	undirected=0; arrows=FALSE; bezier=FALSE;
 	fileName=fn;
 	networkName=(fileName.split ("/")).last();
 	gwWidth=width;
@@ -64,7 +65,8 @@ bool Parser::load(QString fn, int iNS, QString iNC, QString iNSh,
 	randX=0;
 	randY=0;
 	fileFormat= fFormat;
-	
+	two_sm_mode = sm_mode;
+
 	//qDebug()<< "Parser: start() a new parsing thread for file format: " << fileFormat ;
 	if (!isRunning()) 
 		start(QThread::NormalPriority);
@@ -167,7 +169,7 @@ bool Parser::loadDL(){
 				if ( (*it1)!="0"){ //here is an non-zero edge weight...
 					qDebug()<<  "Parser-loadDL(): there is an edge here";
 					edgeWeight=(*it1).toFloat(&floatOK); 
-					undirected=false;
+					undirected=0;
 					arrows=true;
 					bezier=false;
 					emit createEdge(i+1, j+1, edgeWeight, initEdgeColor, undirected, arrows, bezier);
@@ -483,7 +485,7 @@ bool Parser::loadPajek(){
 					//qDebug("Parser-loadPajek(): file with no link colours");
 					edgeColor=initEdgeColor;
 				}
-				undirected=true;
+				undirected=2;
 				arrows=true;
 				bezier=false;
 				qDebug()<< "Parser-loadPajek(): EDGES: Create edge between " << source << " - "<< target;
@@ -520,7 +522,7 @@ bool Parser::loadPajek(){
 					//qDebug("Parser-loadPajek(): file with no link colours");
 					edgeColor=initEdgeColor;
 				}
-				undirected=false;
+				undirected=0;
 				arrows=true;
 				bezier=false;
 				qDebug()<<"Parser-loadPajek(): ARCS: Creating arc from node "<< source << " to node "<< target << " with weight "<< weight;
@@ -533,7 +535,7 @@ bool Parser::loadPajek(){
 				source= lineElement[0].toInt(&ok, 10);
 				fileContainsLinksColors=FALSE;
 				edgeColor=initEdgeColor;
-				undirected=false;
+				undirected=0;
 				arrows=true;
 				bezier=false;
 				for (register int index = 1; index < lineElement.size(); index++) {
@@ -549,7 +551,7 @@ bool Parser::loadPajek(){
 				source= i;
 				fileContainsLinksColors=FALSE;
 				edgeColor=initEdgeColor;
-				undirected=false;
+				undirected=0;
 				arrows=true;
 				bezier=false;
 				for (target = 0; target < lineElement.size(); target ++) {
@@ -592,7 +594,6 @@ bool Parser::loadPajek(){
 	Tries to load the file as adjacency sociomatrix-formatted. If not it returns -1
 */
 bool Parser::loadAdjacency(){
-
 	qDebug("\n\nParser: loadAdjacency()");
 	QFile file ( fileName );
 	if ( ! file.open(QIODevice::ReadOnly )) return false;
@@ -602,7 +603,7 @@ bool Parser::loadAdjacency(){
 	int i=0, j=0,  aNodes=0, newCount=0, lastCount=0;
 	edgeWeight=1.0;
 	bool intOK=FALSE;
-
+	totalLinks=0;
 	i=1;
 	while ( i < 11 &&  !ts.atEnd() )   {
 		str= ts.readLine() ;
@@ -662,10 +663,11 @@ bool Parser::loadAdjacency(){
 			aNodes=lineElement.count();
 			qDebug("Parser-loadAdjacency(): There are %i nodes in this file", aNodes);		
 			for (j=0; j<aNodes; j++) {
-				qDebug("Parser-loadAdjacency(): Calling createNode() for node %i", j+1);
+
 				randX=rand()%gwWidth;
 				randY=rand()%gwHeight;
-				qDebug()<<"Parser-loadAdjacency(): no coords. Using random "<<randX << randY;
+				qDebug()<<"Parser-loadAdjacency(): Calling createNode() for node "<< j+1
+					<<" No coords found. Using random "<<randX <<", " << randY;
 
 				emit createNode( j+1,initNodeSize,  initNodeColor, 
 								initNodeNumberColor, initNodeNumberSize, 				
@@ -675,22 +677,19 @@ bool Parser::loadAdjacency(){
 								);
 			}
 		}
-		qDebug("Parser-loadAdjacency(): Finished creating new nodes");
+		qDebug("Parser-loadAdjacency(): Finished creation of nodes");
 		if ( aNodes != (int) lineElement.count() ) return false;	
 		j=0;
-		qDebug("Parser-loadAdjacency(): Starting creating links");		
 		for (QStringList::Iterator it1 = lineElement.begin(); it1!=lineElement.end(); ++it1)   {
 			if ( (*it1)!="0"){
-				qDebug("Parser-loadAdjacency(): there is a link here");
 				edgeWeight =(*it1).toFloat(&intOK);
-				undirected=false;
+				undirected=0;
 				arrows=true;
 				bezier=false;
 				emit createEdge(i+1, j+1, edgeWeight, initEdgeColor, undirected, arrows, bezier);
 				totalLinks++;
-
-				qDebug("Link from Node i=%i to j=%i", i+1, j+1);
-				qDebug("TotalLinks= %i", totalLinks);
+				qDebug() << "Parser-loadAdjacency(): Link from i=" << i+1 << " to j=" <<  j+1
+					<< "weight=" << edgeWeight << ". TotalLinks= " << totalLinks;
 			}
 
 			j++;
@@ -710,6 +709,100 @@ bool Parser::loadAdjacency(){
 
 
 
+/**
+	Tries to load the file as adjacency sociomatrix-formatted. If not it returns -1
+*/
+bool Parser::loadTwoModeSociomatrix(){
+	qDebug("\n\nParser: loadTwoModeSociomatrix()");
+	QFile file ( fileName );
+	if ( ! file.open(QIODevice::ReadOnly ))
+	    return false;
+	QTextStream ts( &file );
+	QString str;
+	QStringList lineElement;
+	int i=0, j=0,  aNodes=0, newCount=0, lastCount=0;
+	edgeWeight=1.0;
+
+	while (  !ts.atEnd() )  {
+		i++;
+		str= ts.readLine();
+		str=str.simplified();
+		if ( isComment(str) )
+			continue;
+		if ( str.contains("vertices",Qt::CaseInsensitive)
+			|| str.contains("network",Qt::CaseInsensitive)
+			|| str.contains("graph",Qt::CaseInsensitive)
+			|| str.contains("digraph",Qt::CaseInsensitive)
+			|| str.contains("DL",Qt::CaseInsensitive)
+			|| str.contains("list",Qt::CaseInsensitive)
+			|| str.contains("graphml",Qt::CaseInsensitive)
+			|| str.contains("xml",Qt::CaseInsensitive)
+			) {
+			qDebug()<< "*** Parser:loadTwoModeSociomatrix(): Not a two mode sociomatrix-formatted file. Aborting!!";
+			file.close();
+			return false;
+		}
+		if ( str.contains (",")){
+			lineElement=str.split(",");
+			newCount = lineElement.count();
+		}
+		else {
+			lineElement=str.split(" ");
+			newCount = lineElement.count();
+		}
+		qDebug() << str;
+		qDebug() << "newCount "<<newCount << " nodes. We are at i = " << i;
+		if  ( (newCount != lastCount && i>1 )  ) { // line element count differ
+			qDebug()<< "*** Parser:loadTwoModeSociomatrix(): Not a Sociomatrix-formatted file. Aborting!!";
+			file.close();
+			return false;
+		}
+		lastCount=newCount;
+		randX=rand()%gwWidth;
+		randY=rand()%gwHeight;
+		qDebug()<< "Parser-loadTwoModeSociomatrix(): Calling createNode() for node "
+				<< i << " at random x,y: "<<randX << randY;
+		emit createNode( i,initNodeSize, initNodeColor,
+				 initNodeNumberColor, initNodeNumberSize,
+				 QString::number(i), initNodeLabelColor, initNodeLabelSize,
+				 QPointF(randX, randY),
+				 initNodeShape, false
+				 );
+		j=1;
+		qDebug()<< "Parser-loadTwoModeSociomatrix(): reading actor affiliations...";
+		for (QStringList::Iterator it1 = lineElement.begin(); it1!=lineElement.end(); ++it1)   {
+			if ( (*it1)!="0"){
+				qDebug() << "Parser-loadTwoModeSociomatrix(): there is an 1 from "<< i << " to "<<  j;
+				firstModeMultiMap.insert(i, j);
+				secondModeMultiMap.insert(j, i);
+                                QList<int> values;
+                                for (int k = 1; k < i ; ++k) {
+				    qDebug() << "Checking earlier discovered actor k = " << k;
+                                    if ( firstModeMultiMap.contains(k, j) ) {
+					undirected=2;
+                                        arrows=true;
+                                        bezier=false;
+                                        edgeWeight = 1;
+					qDebug() << " Actor " << i << " on the same event as actor " << k << ". Creating edge ";
+                                        emit createEdge(i, k, edgeWeight, initEdgeColor, undirected, arrows, bezier);
+                                        totalLinks++;
+                                    }
+                                }
+
+			}
+			j++;
+		}
+	}
+	file.close();
+	// 0: no format, 1: GraphML, 2:Pajek, 3:Adjacency, 4: Dot, 5:DL, 6:GML, 7: List, 8 List, 9, TwoModeSociomatrix
+	qDebug() << "Parser: Two-mode SM network has been loaded. Tell MW the statistics and network type";
+	emit fileType(9, networkName, aNodes, totalLinks, undirected);
+
+	return true;
+
+}
+
+
 
 
 /**
@@ -781,8 +874,8 @@ void Parser::readGraphML(QXmlStreamReader &xml){
 	bool_node=false;
 	bool_edge=false;
 	bool_key=false;
-	Q_ASSERT(xml.isStartElement() && xml.name() == "graph");
-	
+	//Q_ASSERT(xml.isStartElement() && xml.name() == "graph");
+
 	while (!xml.atEnd()) { //start reading until QXmlStreamReader end().
 		xml.readNext();	//read next token
 	
@@ -807,15 +900,13 @@ void Parser::readGraphML(QXmlStreamReader &xml){
 			else if ( xml.name() == "ShapeNode") {
 				bool_node =  true;
 			}			
-			else if (	 ( 
-							xml.name() == "Geometry" 
-							|| xml.name() == "Fill"
-							|| xml.name() == "BorderStyle"
-							|| xml.name() == "NodeLabel"
-							|| xml.name() == "Shape" 
-						)
-						&& 	bool_node 
-					) {
+			else if ( ( xml.name() == "Geometry"
+					|| xml.name() == "Fill"
+					|| xml.name() == "BorderStyle"
+					|| xml.name() == "NodeLabel"
+					|| xml.name() == "Shape"
+				) && 	bool_node
+				  ) {
 				readGraphMLElementNodeGraphics(xml);
 			}
 			
@@ -863,10 +954,10 @@ void Parser::readGraphMLElementGraph(QXmlStreamReader &xml){
 	QString defaultDirection = xmlStreamAttr.value("edgedefault").toString();
 	qDebug()<< "    edgedefault "<< defaultDirection;
 	if (defaultDirection=="undirected"){
-		undirected = true;
+		undirected = 2;
 	}
 	else {
-		undirected = false;
+		undirected = 0;
 	}
 	networkName = xmlStreamAttr.value("id").toString();
 	qDebug()<< "    graph id  "  << networkName; //store graph id to return it afterwards 
@@ -1024,7 +1115,7 @@ void Parser::readGraphMLElementEdge(QXmlStreamAttributes &xmlStreamAttr){
 	QString s = xmlStreamAttr.value("source").toString();
 	QString t = xmlStreamAttr.value("target").toString();
 	if ( (xmlStreamAttr.value("directed")).toString() == "false") 
-		undirected = "true";
+		undirected = 2;
 	source = nodeNumber [s];
 	target = nodeNumber [t];
 	edgeWeight=initEdgeWeight;
@@ -1389,7 +1480,7 @@ bool Parser::loadDot(){
 	QList<QString> nodeSequence;   //holds edges
 	QList<QString> nodesDiscovered; //holds nodes;
 		
-	undirected=false; arrows=TRUE; bezier=FALSE;
+	undirected=0; arrows=TRUE; bezier=FALSE;
 	source=0, target=0;
 	QFile file ( fileName );
 	if ( ! file.open(QIODevice::ReadOnly )) return false;
@@ -1756,7 +1847,7 @@ bool Parser::loadWeighedList(){
 	bool intOK=false;
 
 	edgeWeight=1.0;
-	undirected=false;
+	undirected=0;
 	arrows=true;
 	bezier=false;
 
@@ -1793,8 +1884,7 @@ bool Parser::loadWeighedList(){
 
 		source =  (lineElement[0]).toInt(&intOK);
 		target =  (lineElement[1]).toInt(&intOK);
-		qDebug() << "	source node " << source;
-		qDebug() << "	target node " << target;
+		qDebug() << "	source node " << source  << " target node " << target;
 
 		edgeWeight=(lineElement[2]).toDouble(&intOK);
 		if (intOK) {
@@ -1806,11 +1896,11 @@ bool Parser::loadWeighedList(){
 		}
 		if (maxNodeCreated < source ) {
 			for ( j = maxNodeCreated ; j != source ; j++ ) {
-				qDebug()<< "	source node " << source
-						<< "is less than maxNodeCreated - we need to create node "<< j+1;
 				randX=rand()%gwWidth;
 				randY=rand()%gwHeight;
-				qDebug()<<"	using random coords "<<randX << " "<< randY;
+				qDebug()<< "	source node " << source
+						<< "is less than maxNodeCreated - creating node "<< j+1
+						<< "using random coords "<<randX << " "<< randY;
 				emit createNode( j+1, initNodeSize,  initNodeColor,
 						 initNodeNumberColor, initNodeNumberSize,
 						 QString::number(j+1), initNodeLabelColor, initNodeLabelSize,
@@ -1822,11 +1912,11 @@ bool Parser::loadWeighedList(){
 		}
 		if (maxNodeCreated < target ) {
 			for ( j = maxNodeCreated ; j != target; j++ ) {
-				qDebug()<< "	target node " << target
-						<< "	is less than maxNodeCreated - creating node "<< j+1;
 				randX=rand()%gwWidth;
 				randY=rand()%gwHeight;
-				qDebug()<<"	using random coords "<<randX << " "<< randY;
+				qDebug()<< "	target node " << target
+						<< "is less than maxNodeCreated - creating node "<< j+1
+						<<" using random coords "<<randX << " "<< randY;
 				emit createNode( j+1, initNodeSize,  initNodeColor,
 						 initNodeNumberColor, initNodeNumberSize,
 						 QString::number(j+1), initNodeLabelColor, initNodeLabelSize,
@@ -1836,10 +1926,10 @@ bool Parser::loadWeighedList(){
 			}
 			maxNodeCreated = target ;
 		}
-		qDebug("Parser-loadWeighedList(): Creating link now... ");
+		qDebug()<< "	Parser-loadWeighedList(): Creating link now... "
+			<< " link from i= " << source << " to j= "<< target << " weight= "<< edgeWeight <<  " TotalLinks=  " << totalLinks+1;
 		emit createEdge(source, target, edgeWeight, initEdgeColor, undirected, arrows, bezier);
 		totalLinks++;
-		qDebug("link from node i=%i to j=%i . TotalLinks= %i ", source, target, totalLinks);
 	} //end ts.stream while here
 	file.close();
 
@@ -1864,8 +1954,8 @@ bool Parser::loadSimpleList(){
 	QStringList lineElement;
 	int i=0, j=0, num=0, source=0, target=0, maxNodeCreated=0;
 	bool intOK=false;
-	
-	edgeWeight=1.0;
+        initEdgeWeight=1.0;
+
 	undirected=false;
 	arrows=true;
 	bezier=false;
@@ -1930,7 +2020,7 @@ bool Parser::loadSimpleList(){
 				qDebug("	there is a link here");
 				emit createEdge(source, target, initEdgeWeight, initEdgeColor, undirected, arrows, bezier);
 				totalLinks++;
-				qDebug("	link from Node i=%i to j=%i . TotalLinks= %i ", source, target, totalLinks);
+                                qDebug() << "link from Node i= "<< source  << "  to j = " <<  target << " weight = "<< initEdgeWeight<< ". TotalLinks =  " << totalLinks;
 			}
 			i++;
 		}
@@ -2008,6 +2098,13 @@ void Parser::run()  {
 		else fileFormat=-1;
 		break;
 
+	case 9:	// twomode sociomatrix, affiliation network matrix
+		if (loadTwoModeSociomatrix() ){
+			qDebug("Parser: OK, this is a two-mode sociomatrix (.tsm) network");
+		}
+		else fileFormat=-1;
+		break;
+
 	default:	//GraphML
 		if (loadGraphML() ){
 			qDebug("Parser: this is a GraphML network");
