@@ -1,6 +1,6 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.81
+ version: 0.90
  Written in Qt 4.4
  
                          parser.h  -  description
@@ -34,7 +34,7 @@ using namespace std;
 #include <QMutex>
 #include <QObject>
 #include <QtXml>	
-
+#include <QMultiMap>
 
 /** 	
 	Main class for network file parsing and loading
@@ -44,7 +44,8 @@ class Parser :  public QThread {
 	Q_OBJECT
 public:
 	
-	bool load(QString fn, int iNS, QString iNC, QString iNSh, QString iNNC, int iNNS, QString iNLC, int iNLS , QString iEC, int w, int h, int isListWithWeights);
+	bool load(QString fn, int iNS, QString iNC, QString iNSh, QString iNNC,
+		 int iNNS, QString iNLC, int iNLS , QString iEC, int w, int h, int format, int sm_mode);
 	bool loadPajek();
 	bool loadAdjacency();
 	bool loadDot();
@@ -54,6 +55,7 @@ public:
 	bool loadDL();
 	bool loadSimpleList();
 	bool loadWeighedList();
+	bool loadTwoModeSociomatrix();
 
 	void dotProperties(QString str, float &, QString &label, QString &shape, QString &color, QString &fontName, QString &fontColor );
 	void readGraphML (QXmlStreamReader &);
@@ -73,13 +75,13 @@ public:
 	bool isComment(QString str);  
 signals:
 	void createNode( 
-					int num, int size, QString color, 
-					QString numColor, int numSize, 
-					QString label, QString lColor, int lSize, 
-					QPointF p, 
-					QString shape, bool signalMW);
+			int num, int size, QString color,
+			QString numColor, int numSize,
+			QString label, QString lColor, int lSize,
+			QPointF p,
+			QString shape, bool signalMW);
 
-	void createEdge (int, int, float, QString, bool, bool, bool);
+	void createEdge (int, int, float, QString, int, bool, bool);
 	void fileType(int, QString, int, int, bool);
 	void removeDummyNode (int);
 	
@@ -89,17 +91,17 @@ private:
 	QMutex mutex;
 	QHash<QString, int> nodeNumber;
 	QHash<QString, QString> keyFor, keyName, keyType, keyDefaultValue ;
+	QMultiMap<int, int> firstModeMultiMap, secondModeMultiMap;
 	QXmlStreamReader *xml;
 	QString fileName, networkName, initNodeColor, initEdgeColor, initNodeShape, initNodeNumberColor, initNodeLabelColor;
 	QString nodeColor, edgeColor, edgeType, nodeShape, nodeLabel, edgeLabel, nodeNumberColor, nodeLabelColor;
-	  
 	int gwWidth, gwHeight;
-	int totalLinks, aNodes, fileFormat;
+	int totalLinks, aNodes, fileFormat, two_sm_mode, undirected;
 	int initNodeSize,  initNodeNumberSize, nodeNumberSize, initNodeLabelSize, nodeLabelSize, source, target, nodeSize;
 	float initEdgeWeight, edgeWeight, arrowSize;
 	float bez_p1_x,bez_p1_y, bez_p2_x, bez_p2_y;
 	  
-	bool undirected, arrows, bezier, conv_OK;
+	bool arrows, bezier, conv_OK;
 	bool bool_key, bool_node, bool_edge;
 	
 	QString key_id, key_value, key_name, key_what, key_type;
